package com.ruoyi.project.business.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.project.business.domain.train.TtAssessResult;

import java.util.List;

/**
 * 答卷Mapper接口
 * 
 * @author ruoyi
 * @date 2024-07-04
 */
public interface TtAssessResultMapper extends BaseMapper<TtAssessResult>
{
    /**
     * 查询答卷
     * 
     * @param id 答卷主键
     * @return 答卷
     */
    public TtAssessResult selectTtAssessResultById(Long id);

    /**
     * 查询答卷列表
     * 
     * @param ttAssessResult 答卷
     * @return 答卷集合
     */
    public List<TtAssessResult> selectTtAssessResultList(TtAssessResult ttAssessResult);

    /**
     * 新增答卷
     * 
     * @param ttAssessResult 答卷
     * @return 结果
     */
    public int insertTtAssessResult(TtAssessResult ttAssessResult);

    /**
     * 修改答卷
     * 
     * @param ttAssessResult 答卷
     * @return 结果
     */
    public int updateTtAssessResult(TtAssessResult ttAssessResult);

    /**
     * 删除答卷
     * 
     * @param id 答卷主键
     * @return 结果
     */
    public int deleteTtAssessResultById(Long id);

    /**
     * 批量删除答卷
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTtAssessResultByIds(Long[] ids);

    public int insertTtAssessResultBatch(List<TtAssessResult> ttAssessResultList);
}
